@@ -1,5 +1,5 @@
-# For some reason these variables have to be declared globally, otherwise the
-# scoping within RUnit breaks the tests.
+# For some reason these variables have to be declared explicitly and globally, 
+# otherwise the scoping within RUnit breaks the tests.
 absdiff <<- function(...) UseFunction('absdiff', ...)
 
 guard(absdiff.1, c(
@@ -12,7 +12,7 @@ guard(absdiff.2, c(
   function(a,b) is.numeric(a) && is.numeric(b),
   function(a,b) a < b
 ))
-absdiff.2 <<- function(a, b) b - a
+absdiff.2 <- function(a, b) b - a
 
 guard(absdiff.21, ! is.numeric(a) || ! is.numeric(b))
 absdiff.21 <<- function(a, b) absdiff(as.double(a), as.double(b))
@@ -34,15 +34,33 @@ absdiff.3 <<- function(a) a * 2
 guard(absdiff.4, TRUE)
 absdiff.4 <<- function(a) a + 1
 
+cat("Objects after definitions:\n")
+cat(ls())
+cat("\n")
+
+# This doesn't work either even though absdiff was created??
+#cat("Prepopulating results\n")
+#result.1 <<- absdiff(18,6)
+#result.2 <<- absdiff(6,18)
+#result.21.a <<- absdiff('6', 18)
+#result.21.b <<- absdiff(6, '18')
+#result.21.c <<- absdiff('6', '18')
+#cat("Done prepopulating\n")
+
 ## TESTS
+# Use this construction to get around runit environment cleaning. This way we
+# actually test that the parent function is being defined and the concrete 
+# ones are being attached properly.
 test.absdiff.1 <- function()
 {
   checkTrue(12 == absdiff(18,6))
+  #checkTrue(12 == result.1)
 }
 
 test.absdiff.2 <- function()
 {
   checkTrue(12 == absdiff(6,18))
+  #checkTrue(12 == result.2)
 }
 
 test.absdiff.21 <- function()
@@ -50,6 +68,9 @@ test.absdiff.21 <- function()
   checkTrue(12 == absdiff('6', 18))
   checkTrue(12 == absdiff(6,'18'))
   checkTrue(12 == absdiff('6','18'))
+  #checkTrue(12 == result.21.a)
+  #checkTrue(12 == result.21.b)
+  #checkTrue(12 == result.21.c)
 }
 
 test.absdiff.3 <- function()
@@ -91,9 +112,11 @@ interpolate <<- function(cfg, a,b) { }
 
 
 ## TESTS FOR ENSURE
+logarithm <<- function(...) UseFunction('logarithm',...)
+
 guard(logarithm.1, is.numeric(x))
-logarithm.1 <<- function(x) logarithm(x, exp(1))
 ensure(logarithm.1, ! is.nan(result) && ! is.infinite(result))
+logarithm.1 <<- function(x) logarithm(x, exp(1))
 
 guard(logarithm.default1, TRUE)
 logarithm.default1 <<- function(x) logarithm(as.numeric(x))
@@ -105,19 +128,19 @@ guard(logarithm.default2, TRUE)
 logarithm.default2 <<- function(x,y) logarithm(as.numeric(x), as.numeric(y))
 
 
-test.logarithm.int <- function()
+test.logarithm.int <<- function()
 {
   checkTrue(0 == logarithm(1,5))
   checkTrue(3 == logarithm(y=2, 8))
 }
 
-test.logarithm.neg <- function()
+test.logarithm.neg <<- function()
 {
   cat("Expecting failed assertion\n")
   checkException(logarithm(-1))
 }
 
-test.logarithm.paths <- function()
+test.logarithm.paths <<- function()
 {
   # Assertion is on logarithm.1
   checkException(logarithm(-1))
